﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using drawtool.DrawingShapes;

namespace drawtool
{
    public partial class Page : UserControl
    {
        public DrawState CurrentState { get; set; }

        public Page()
        {
            InitializeComponent();

            CurrentState = new DrawState();
            CurrentState.StateChangedEvent += new DrawState.StateChanged(CurrentStateChanged);
            CurrentState.ChangeState(DrawStateEnum.Cursor);

            //Line test = new Line();
            //test.X1 = 30;
            //test.X2 = 100;
            //test.Y1 = 20;
            //test.Y2 = 150;
            //test.Stroke = new SolidColorBrush(Colors.Blue);
            //drawArea.Children.Add(test);
            
        }

        public void CurrentStateChanged(DrawStateEnum state)
        {
            // 状態によってボタンの色を変更します。
            
            switch (state)
            {
                case DrawStateEnum.Cursor:
                    btnCursor.Background = new SolidColorBrush(Colors.Red);
                    btnEllipse.Background = new SolidColorBrush(Colors.Blue);
                    btnLine.Background = new SolidColorBrush(Colors.Blue);
                    btnRectangle.Background = new SolidColorBrush(Colors.Blue);
                    break;
                case DrawStateEnum.Ellipse:
                    btnCursor.Background = new SolidColorBrush(Colors.Blue);
                    btnEllipse.Background = new SolidColorBrush(Colors.Red);
                    btnLine.Background = new SolidColorBrush(Colors.Blue);
                    btnRectangle.Background = new SolidColorBrush(Colors.Blue);
                    break;
                case DrawStateEnum.Line:
                    btnCursor.Background = new SolidColorBrush(Colors.Blue);
                    btnEllipse.Background = new SolidColorBrush(Colors.Blue);
                    btnLine.Background = new SolidColorBrush(Colors.Red);
                    btnRectangle.Background = new SolidColorBrush(Colors.Blue);
                    break;
                case DrawStateEnum.Rectangle:
                    btnCursor.Background = new SolidColorBrush(Colors.Blue);
                    btnEllipse.Background = new SolidColorBrush(Colors.Blue);
                    btnLine.Background = new SolidColorBrush(Colors.Blue);
                    btnRectangle.Background = new SolidColorBrush(Colors.Red);
                    break;
            }



        }

        private void btnCursor_Click(object sender, RoutedEventArgs e)
        {
            CurrentState.ChangeState(DrawStateEnum.Cursor);
        }

        private void btnRectangle_Click(object sender, RoutedEventArgs e)
        {
            CurrentState.ChangeState(DrawStateEnum.Rectangle);
        }

        private void btnEllipse_Click(object sender, RoutedEventArgs e)
        {
            CurrentState.ChangeState(DrawStateEnum.Ellipse);
        }

        private void btnLine_Click(object sender, RoutedEventArgs e)
        {
            CurrentState.ChangeState(DrawStateEnum.Line);
        }

        private void drawArea_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            switch (CurrentState.CurrentState)
            {
                case DrawStateEnum.Cursor:
                    break;
                case DrawStateEnum.Ellipse:
                    Point point = e.GetPosition(drawArea);
                    Shape shape = new DrawEllipse().GetShape(point);
                    Canvas.SetTop(shape, point.Y);
                    Canvas.SetLeft(shape, point.X);
                    drawArea.Children.Add(shape);
                    CurrentState.ChangeState(DrawStateEnum.Cursor);
                    break;
                case DrawStateEnum.Line:
                    drawArea.Children.Add(new DrawLine().GetShape(e.GetPosition(drawArea)));
                    CurrentState.ChangeState(DrawStateEnum.Cursor);
                    break;
                case DrawStateEnum.Rectangle:
                    Point rectPoint = e.GetPosition(drawArea);
                    Shape rect = new DrawRectangle().GetShape(rectPoint);
                    Canvas.SetTop(rect, rectPoint.Y);
                    Canvas.SetLeft(rect, rectPoint.X);
                    drawArea.Children.Add(rect);
                    CurrentState.ChangeState(DrawStateEnum.Cursor);
                    break;
            }
        }
    }
}
